==> onboarding-springboot-0.11.1-sources.jar: org/kie/kogito/examples/onboarding/OnboardingModel.java <==
package org.kie.kogito.examples.onboarding;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogito-codegen", reference = "onboarding.onboarding", name = "Onboarding", hidden = false)
public class OnboardingModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("manager", this.manager);
        params.put("employeeId", this.employeeId);
        params.put("payroll", this.payroll);
        params.put("employee", this.employee);
        params.put("message", this.message);
        params.put("department", this.department);
        params.put("email", this.email);
        params.put("status", this.status);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.manager = (java.lang.String) params.get("manager");
        this.employeeId = (java.lang.String) params.get("employeeId");
        this.payroll = (org.kie.kogito.examples.onboarding.Payroll) params.get("payroll");
        this.employee = (org.kie.kogito.examples.onboarding.Employee) params.get("employee");
        this.message = (java.lang.String) params.get("message");
        this.department = (java.lang.String) params.get("department");
        this.email = (java.lang.String) params.get("email");
        this.status = (java.lang.String) params.get("status");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "manager")
    @javax.validation.Valid()
    private java.lang.String manager;

    public java.lang.String getManager() {
        return manager;
    }

    public void setManager(java.lang.String manager) {
        this.manager = manager;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "employeeId")
    @javax.validation.Valid()
    private java.lang.String employeeId;

    public java.lang.String getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(java.lang.String employeeId) {
        this.employeeId = employeeId;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "payroll")
    @javax.validation.Valid()
    private org.kie.kogito.examples.onboarding.Payroll payroll;

    public org.kie.kogito.examples.onboarding.Payroll getPayroll() {
        return payroll;
    }

    public void setPayroll(org.kie.kogito.examples.onboarding.Payroll payroll) {
        this.payroll = payroll;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "employee")
    @javax.validation.Valid()
    private org.kie.kogito.examples.onboarding.Employee employee;

    public org.kie.kogito.examples.onboarding.Employee getEmployee() {
        return employee;
    }

    public void setEmployee(org.kie.kogito.examples.onboarding.Employee employee) {
        this.employee = employee;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "message")
    @javax.validation.Valid()
    private java.lang.String message;

    public java.lang.String getMessage() {
        return message;
    }

    public void setMessage(java.lang.String message) {
        this.message = message;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "department")
    @javax.validation.Valid()
    private java.lang.String department;

    public java.lang.String getDepartment() {
        return department;
    }

    public void setDepartment(java.lang.String department) {
        this.department = department;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "email")
    @javax.validation.Valid()
    private java.lang.String email;

    public java.lang.String getEmail() {
        return email;
    }

    public void setEmail(java.lang.String email) {
        this.email = email;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "status")
    @javax.validation.Valid()
    private java.lang.String status;

    public java.lang.String getStatus() {
        return status;
    }

    public void setStatus(java.lang.String status) {
        this.status = status;
    }
}

==> onboarding-springboot-0.14.0-sources.jar: org/kie/kogito/examples/onboarding/OnboardingModel.java <==
package org.kie.kogito.examples.onboarding;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogito-codegen", reference = "onboarding.onboarding", name = "Onboarding", hidden = false)
public class OnboardingModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("manager", this.manager);
        params.put("employeeId", this.employeeId);
        params.put("payroll", this.payroll);
        params.put("employee", this.employee);
        params.put("message", this.message);
        params.put("department", this.department);
        params.put("email", this.email);
        params.put("status", this.status);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.manager = (java.lang.String) params.get("manager");
        this.employeeId = (java.lang.String) params.get("employeeId");
        this.payroll = (org.kie.kogito.examples.onboarding.Payroll) params.get("payroll");
        this.employee = (org.kie.kogito.examples.onboarding.Employee) params.get("employee");
        this.message = (java.lang.String) params.get("message");
        this.department = (java.lang.String) params.get("department");
        this.email = (java.lang.String) params.get("email");
        this.status = (java.lang.String) params.get("status");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "manager")
    @javax.validation.Valid()
    private java.lang.String manager;

    public java.lang.String getManager() {
        return manager;
    }

    public void setManager(java.lang.String manager) {
        this.manager = manager;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "employeeId")
    @javax.validation.Valid()
    private java.lang.String employeeId;

    public java.lang.String getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(java.lang.String employeeId) {
        this.employeeId = employeeId;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "payroll")
    @javax.validation.Valid()
    private org.kie.kogito.examples.onboarding.Payroll payroll;

    public org.kie.kogito.examples.onboarding.Payroll getPayroll() {
        return payroll;
    }

    public void setPayroll(org.kie.kogito.examples.onboarding.Payroll payroll) {
        this.payroll = payroll;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "employee")
    @javax.validation.Valid()
    private org.kie.kogito.examples.onboarding.Employee employee;

    public org.kie.kogito.examples.onboarding.Employee getEmployee() {
        return employee;
    }

    public void setEmployee(org.kie.kogito.examples.onboarding.Employee employee) {
        this.employee = employee;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "message")
    @javax.validation.Valid()
    private java.lang.String message;

    public java.lang.String getMessage() {
        return message;
    }

    public void setMessage(java.lang.String message) {
        this.message = message;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "department")
    @javax.validation.Valid()
    private java.lang.String department;

    public java.lang.String getDepartment() {
        return department;
    }

    public void setDepartment(java.lang.String department) {
        this.department = department;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "email")
    @javax.validation.Valid()
    private java.lang.String email;

    public java.lang.String getEmail() {
        return email;
    }

    public void setEmail(java.lang.String email) {
        this.email = email;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "status")
    @javax.validation.Valid()
    private java.lang.String status;

    public java.lang.String getStatus() {
        return status;
    }

    public void setStatus(java.lang.String status) {
        this.status = status;
    }

    public OnboardingModelOutput toOutput() {
        OnboardingModelOutput result = new OnboardingModelOutput();
        result.setId(getId());
        result.setManager(getManager());
        result.setEmployeeId(getEmployeeId());
        result.setPayroll(getPayroll());
        result.setEmployee(getEmployee());
        result.setMessage(getMessage());
        result.setDepartment(getDepartment());
        result.setEmail(getEmail());
        result.setStatus(getStatus());
        return result;
    }
}
